@@ -1,4 +1,4 @@
-pub(crate) trait IPeriod {
+pub trait IPeriod {
     fn get_code(&self) -> i32;
     fn year(&self) -> i16;
     fn month(&self) -> i16;
@@ -6,7 +6,7 @@ pub(crate) trait IPeriod {
 }
 
 #[derive(Debug, Copy, Clone)]
-pub(crate) struct Period {
+pub struct Period {
     code: i32
 }
 
@@ -30,10 +30,10 @@ impl Period {
     fn new() -> Period {
         Period { code: 0 }
     }
-    pub(crate) fn get(_code: i32) -> Period {
+    pub fn get(_code: i32) -> Period {
         Period { code: _code }
     }
-    fn get_with_year_month(_year: i16, _month: i16) -> Period {
+    pub fn get_with_year_month(_year: i16, _month: i16) -> Period {
         Period { code: (i32::from(_year) * 100 + i32::from(_month)) }
     }
 }
\ No newline at end of file
