@@ -3,11 +3,11 @@ use crate::service::period::IPeriod;
 use crate::factories::bundle_props::{BundleProps};
 use crate::service::history_result_errors::HistoryResultError;
 
-trait IServiceLegalios {
+pub trait IServiceLegalios {
     fn get_bundle(&self, _period: &dyn IPeriod) -> Result<BundleProps, HistoryResultError>;
 }
 
-struct ServiceLegalios {
+pub struct ServiceLegalios {
     builder: BundleBuilder
 }
 
@@ -23,7 +23,7 @@ impl IServiceLegalios for ServiceLegalios {
 
 #[allow(dead_code)]
 impl ServiceLegalios {
-    fn new() -> ServiceLegalios {
+    pub fn new() -> ServiceLegalios {
         ServiceLegalios {
             builder: BundleBuilder::new()
         }
